@@ -4,8 +4,8 @@ import pytest
 from pydantic import ValidationError
 from requests import HTTPError
 
-from marketpalce_handler.config import settings
-from marketpalce_handler.exceptions import InvalidStatusException
+from marketplace_handler.config import settings
+from marketplace_handler.exceptions import InvalidStatusException
 
 
 class TestWildberries:
